==> aroundme_0_5_0.zip: aroundme_0_5_0/aroundme/language/1/barnraiser_01/g_group.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'g_common.lang.php');

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_activities'] = 						"events";
$lang['hdr_library'] = 							"wiki";
$lang['hdr_recommended_s'] = 					"recommended discussions";
$lang['hdr_recommended_b'] = 					"recommended blogs";
$lang['hdr_statistics'] = 						"statistics";
$lang['hdr_polls'] = 							"polls";
$lang['hdr_tasks'] = 							"tasks";
$lang['section_group_summary'] = 				"introducing this group";


//A HREF TAGS (links)
$lang['href_join'] = 							"join";


//BODY TEXT
$lang['txt_group_apply'] = 						"want to join this group?";
$lang['txt_hidden'] = 							"hidden";

?>

==> aroundme_0_5_2.zip: aroundme_0_5_2/aroundme/language/1/barnraiser_01/g_group.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'g_common.lang.php');

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_activities'] = 						"events";
$lang['hdr_library'] = 							"wiki";
$lang['hdr_recommended_s'] = 					"recommended discussions";
$lang['hdr_recommended_b'] = 					"recommended blogs";
$lang['hdr_statistics'] = 						"statistics";
$lang['hdr_polls'] = 							"polls";
$lang['hdr_tasks'] = 							"tasks";
$lang['section_group_summary'] = 				"introducing this group";
$lang['hdr_tag'] = 								"tags";


//A HREF TAGS (links)
$lang['href_join'] = 							"join";


// SUB
$lang['sub_update_tag'] = 						"update my tags";


//BODY TEXT
$lang['txt_group_apply'] = 						"want to join this group?";
$lang['txt_hidden'] = 							"hidden";
$lang['txt_tag_intro'] = 						"This group has been tagged with";
$lang['txt_tag_network'] = 						"My network have tagged this group with";
$lang['txt_tag_group'] = 						"This group has tagged this group with";

?>
